summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--kaddressbook/kcmconfigs/kabconfigwidget.cpp2
-rw-r--r--kandy/src/mobilegui.cpp20
-rw-r--r--kioslaves/sieve/sieve.cpp2
-rw-r--r--kitchensync/src/aboutpage.cpp4
-rw-r--r--kitchensync/src/memberinfo.cpp2
-rw-r--r--kmail/kmreaderwin.cpp6
-rw-r--r--kmobile/kioslave/kio_mobile.cpp2
-rw-r--r--knotes/knotesapp.cpp2
-rw-r--r--kontact/src/mainwindow.cpp4
-rw-r--r--wizards/overviewpage.cpp4
10 files changed, 24 insertions, 24 deletions
diff --git a/kaddressbook/kcmconfigs/kabconfigwidget.cpp b/kaddressbook/kcmconfigs/kabconfigwidget.cpp
index 9b826b9e..bbed600e 100644
--- a/kaddressbook/kcmconfigs/kabconfigwidget.cpp
+++ b/kaddressbook/kcmconfigs/kabconfigwidget.cpp
@@ -63,7 +63,7 @@ KABConfigWidget::KABConfigWidget( TQWidget *parent, const char *name )
TQBoxLayout *boxLayout = new TQVBoxLayout( groupBox->layout() );
boxLayout->setAlignment( TQt::AlignTop );
- mViewsSingleClickBox = new TQCheckBox( i18n( "Honor KDE single click" ), groupBox, "msingle" );
+ mViewsSingleClickBox = new TQCheckBox( i18n( "Honor TDE single click" ), groupBox, "msingle" );
boxLayout->addWidget( mViewsSingleClickBox );
mNameParsing = new TQCheckBox( i18n( "Automatic name parsing for new addressees" ), groupBox, "mparse" );
diff --git a/kioslaves/sieve/sieve.cpp b/kioslaves/sieve/sieve.cpp
index 8cba6a50..8132834a 100644
--- a/kioslaves/sieve/sieve.cpp
+++ b/kioslaves/sieve/sieve.cpp
@@ -361,7 +361,7 @@ bool kio_sieveProtocol::connect(bool useTLSIfAvailable)
// Attempt to start TLS
if ( !m_allowUnencrypted && !canUseTLS() ) {
- error( ERR_SLAVE_DEFINED, i18n("Can not use TLS. Please enable TLS in the KDE cryptography setting.") );
+ error( ERR_SLAVE_DEFINED, i18n("Can not use TLS. Please enable TLS in the TDE cryptography setting.") );
disconnect();
return false;
}
diff --git a/kitchensync/src/aboutpage.cpp b/kitchensync/src/aboutpage.cpp
index 6d884f9f..f2683996 100644
--- a/kitchensync/src/aboutpage.cpp
+++ b/kitchensync/src/aboutpage.cpp
@@ -66,9 +66,9 @@ AboutPage::AboutPage( TQWidget *parent )
part->begin( KURL( location ) );
- TQString appName( i18n( "KDE KitchenSync" ) );
+ TQString appName( i18n( "TDE KitchenSync" ) );
TQString catchPhrase( i18n( "Get Synchronized!" ) );
- TQString quickDescription( i18n( "The KDE Synchronization Tool" ) );
+ TQString quickDescription( i18n( "The TDE Synchronization Tool" ) );
part->write( content.arg( TQFont().pointSize() + 2 ).arg( appName )
.arg( catchPhrase ).arg( quickDescription ).arg( htmlText() ) );
diff --git a/kitchensync/src/memberinfo.cpp b/kitchensync/src/memberinfo.cpp
index 35fd9272..69ae8986 100644
--- a/kitchensync/src/memberinfo.cpp
+++ b/kitchensync/src/memberinfo.cpp
@@ -51,7 +51,7 @@ TQString MemberInfo::name() const
if ( nameMap.isEmpty() ) {
nameMap.insert( "file-sync", i18n( "File" ) );
nameMap.insert( "palm-sync", i18n( "Palm" ) );
- nameMap.insert( "tdepim-sync", i18n( "KDE PIM" ) );
+ nameMap.insert( "tdepim-sync", i18n( "TDE PIM" ) );
nameMap.insert( "kio-sync", i18n( "Remote File" ) );
nameMap.insert( "irmc-sync", i18n( "Mobile Phone" ) );
nameMap.insert( "evo2-sync", i18n( "Evolution" ) );
diff --git a/kmail/kmreaderwin.cpp b/kmail/kmreaderwin.cpp
index cb4bd2e2..beb7c249 100644
--- a/kmail/kmreaderwin.cpp
+++ b/kmail/kmreaderwin.cpp
@@ -1324,7 +1324,7 @@ void KMReaderWin::displayAboutPage()
{
TQString info =
i18n("%1: KMail version; %2: help:// URL; %3: homepage URL; "
- "%4: prior KMail version; %5: prior KDE version; "
+ "%4: prior KMail version; %5: prior TDE version; "
"%6: generated list of new features; "
"%7: First-time user text (only shown on first start); "
"%8: generated list of important changes; "
@@ -1339,7 +1339,7 @@ void KMReaderWin::displayAboutPage()
"new versions of KMail</li></ul>\n"
"%8\n" // important changes
"<p>Some of the new features in this release of KMail include "
- "(compared to KMail %4, which is part of KDE %5):</p>\n"
+ "(compared to KMail %4, which is part of TDE %5):</p>\n"
"<ul>\n%6</ul>\n"
"%7\n"
"<p>We hope that you will enjoy KMail.</p>\n"
@@ -1348,7 +1348,7 @@ void KMReaderWin::displayAboutPage()
.arg(KMAIL_VERSION) // KMail version
.arg("help:/kmail/index.html") // KMail help:// URL
.arg("http://kontact.kde.org/kmail/") // KMail homepage URL
- .arg("1.8").arg("3.4"); // prior KMail and KDE version
+ .arg("1.8").arg("3.4"); // prior KMail and TDE version
TQString featureItems;
for ( int i = 0 ; i < numKMailNewFeatures ; i++ )
diff --git a/kmobile/kioslave/kio_mobile.cpp b/kmobile/kioslave/kio_mobile.cpp
index a8888579..e359b902 100644
--- a/kmobile/kioslave/kio_mobile.cpp
+++ b/kmobile/kioslave/kio_mobile.cpp
@@ -602,7 +602,7 @@ void KMobileProtocol::listDir(const KURL &url)
PRINT_DEBUG << TQString("listDir(%1)\n").arg(url.path());
if (!m_dev.isKMobileAvailable()) {
- error( KIO::ERR_CONNECTION_BROKEN, i18n("KDE Mobile Device Manager") );
+ error( KIO::ERR_CONNECTION_BROKEN, i18n("TDE Mobile Device Manager") );
return;
}
diff --git a/knotes/knotesapp.cpp b/knotes/knotesapp.cpp
index 27c13ee5..964309c5 100644
--- a/knotes/knotesapp.cpp
+++ b/knotes/knotesapp.cpp
@@ -103,7 +103,7 @@ KNotesApp::KNotesApp()
// create the dock widget...
KWin::setSystemTrayWindowFor( winId(), tqt_xrootwin() );
- TQToolTip::add( this, i18n( "KNotes: Sticky notes for KDE" ) );
+ TQToolTip::add( this, i18n( "KNotes: Sticky notes for TDE" ) );
setBackgroundMode( X11ParentRelative );
setPixmap( KSystemTray::loadSizedIcon( "knotes", TQWidget::width() ) );
diff --git a/kontact/src/mainwindow.cpp b/kontact/src/mainwindow.cpp
index 88be77c7..fb39e64f 100644
--- a/kontact/src/mainwindow.cpp
+++ b/kontact/src/mainwindow.cpp
@@ -298,9 +298,9 @@ void MainWindow::paintAboutScreen( const TQString& msg )
mIntroPart->begin( KURL( location ) );
- TQString appName( i18n( "KDE Kontact" ) );
+ TQString appName( i18n( "TDE Kontact" ) );
TQString catchPhrase( i18n( "Get Organized!" ) );
- TQString quickDescription( i18n( "The KDE Personal Information Management Suite" ) );
+ TQString quickDescription( i18n( "The TDE Personal Information Management Suite" ) );
mIntroPart->write( content.arg( TQFont().pointSize() + 2 ).arg( appName )
.arg( catchPhrase ).arg( quickDescription ).arg( msg ) );
diff --git a/wizards/overviewpage.cpp b/wizards/overviewpage.cpp
index 8dcea2bb..1d2ef06c 100644
--- a/wizards/overviewpage.cpp
+++ b/wizards/overviewpage.cpp
@@ -46,7 +46,7 @@ OverViewPage::OverViewPage( TQWidget *parent, const char *name )
TQGridLayout *layout = new TQGridLayout( this, 7, 4, KDialog::marginHint(),
KDialog::spacingHint() );
- const TQString msg = i18n( "KDE Groupware Wizard" );
+ const TQString msg = i18n( "TDE Groupware Wizard" );
TQLabel *label = new TQLabel( "<qt><b><u><h2>" + msg + "</h2></u></b></qt>" , this );
layout->addMultiCellWidget( label, 0, 0, 0, 2 );
@@ -58,7 +58,7 @@ OverViewPage::OverViewPage( TQWidget *parent, const char *name )
layout->addWidget( label, 1, 0 );
layout->setRowSpacing( 1, 20 );
- label = new TQLabel( i18n( "Select the type of server you want connect your KDE to:" ), this );
+ label = new TQLabel( i18n( "Select the type of server you want TDE to connect:" ), this );
layout->addMultiCellWidget( label, 2, 2, 0, 3 );
TQPushButton *button;
diff --git a/kandy/src/mobilegui.cpp b/kandy/src/mobilegui.cpp
index 908837c4..00cfea89 100644
--- a/kandy/src/mobilegui.cpp
+++ b/kandy/src/mobilegui.cpp
@@ -490,7 +490,7 @@ void MobileGui::readKabc()
warnKabState( LOADED );
- emit statusMessage( i18n( "Reading KDE address book..." ) );
+ emit statusMessage( i18n( "Reading TDE address book..." ) );
mSyncer->mKabEntries.clear();
@@ -640,7 +640,7 @@ void MobileGui::readKabc()
// Display KAB entries
updateKabBook();
- emit transienStatusMessage( i18n( "Read KDE address book." ) );
+ emit transienStatusMessage( i18n( "Read TDE address book." ) );
setKabState( LOADED );
}
@@ -948,7 +948,7 @@ void MobileGui::writeKabc()
addressBook->save( ticket );
- emit transienStatusMessage( i18n( "Wrote KDE address book." ) );
+ emit transienStatusMessage( i18n( "Wrote TDE address book." ) );
setKabState( LOADED );
}
@@ -1272,7 +1272,7 @@ void MobileGui::mergePhonebooks()
//
// Put KDE Address Book list into Common List
//
for ( i = 0; i < mSyncer->mKabEntries.count(); i++ )
@@ -1325,7 +1325,7 @@ void MobileGui::mergePhonebooks()
switch ( msg->exec() ) {
case 1:
// Use KDE Address Book Entry
mobileEntry->mPhone = theCommonEntry->mKabEntry->mPhone;
mobileEntry->mName = theCommonEntry->mKabEntry->mName;
mobileEntry->mOn = true;
@@ -1526,19 +1526,19 @@ void MobileGui::setKabState( ABState newState )
{
switch ( mKabState ) {
case UNLOADED:
- groupBox3->setTitle( tr2i18n( "KDE Address Book" ) );
+ groupBox3->setTitle( tr2i18n( "TDE Address Book" ) );
mReadKabButton->setEnabled( true );
PushButton8->setEnabled( false );
break;
case LOADED:
if ( newState == MODIFIED ) {
- groupBox3->setTitle( tr2i18n( "KDE Address Book (modified)" ) );
+ groupBox3->setTitle( tr2i18n( "TDE Address Book (modified)" ) );
mReadKabButton->setEnabled( true );
PushButton8->setEnabled( true );
} else
if ( newState == UNLOADED ) {
- groupBox3->setTitle( tr2i18n( "KDE Address Book" ) );
+ groupBox3->setTitle( tr2i18n( "TDE Address Book" ) );
mReadKabButton->setEnabled( true );
PushButton8->setEnabled( false );
}
@@ -1546,7 +1546,7 @@ void MobileGui::setKabState( ABState newState )
case MODIFIED:
if ( newState != MODIFIED ) {
- groupBox3->setTitle( tr2i18n( "KDE Address Book" ) );
+ groupBox3->setTitle( tr2i18n( "TDE Address Book" ) );
mReadKabButton->setEnabled( true );
PushButton8->setEnabled( false );
}
@@ -1561,7 +1561,7 @@ void MobileGui::warnKabState( ABState newState )
{
if ( ( mKabState == MODIFIED ) && ( newState != MODIFIED ) ) {
TQString text = "<qt><b>" + i18n( "Warning" ) + "</b><br>";
- text += i18n( "The KDE address book contains unsaved changes." ) +
+ text += i18n( "The TDE address book contains unsaved changes." ) +
"<br></qt>";
TQMessageBox *msg = new TQMessageBox( i18n( "Unsaved Changes" ), text,
@@ -1272,7 +1272,7 @@ void MobileGui::mergePhonebooks()
//
- // Put KDE Address Book list into Common List
+ // Put TDE Address Book list into Common List
//
for ( i = 0; i < mSyncer->mKabEntries.count(); i++ )
@@ -1325,7 +1325,7 @@ void MobileGui::mergePhonebooks()
switch ( msg->exec() ) {
case 1:
- // Use KDE Address Book Entry
+ // Use TDE Address Book Entry
mobileEntry->mPhone = theCommonEntry->mKabEntry->mPhone;
mobileEntry->mName = theCommonEntry->mKabEntry->mName;